AFRL labeling Sensor Info (sarpy.annotation.afrl_elements.DetailSensorInfo)
===========================================================================

.. automodule:: sarpy.annotation.afrl_elements.DetailSensorInfo
    :members:
    :show-inheritance:
    :inherited-members:
